aboutsummaryrefslogtreecommitdiff
path: root/src/driver/driver.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/driver/driver.hh')
-rw-r--r--src/driver/driver.hh7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/driver/driver.hh b/src/driver/driver.hh
index 9cd0d1f..149fa0d 100644
--- a/src/driver/driver.hh
+++ b/src/driver/driver.hh
@@ -211,10 +211,9 @@ struct state
int N_horizons;
- // this vector is of size N_horizons+1,
- // and is indexed with a "horizon number" hn
- // which is (hopefully) always in the range 1 <= hn <= N_horizons
- vector<AH_info *> AH_info_ptrs;
+ // --> array of size N_horizons+1,
+ // indexed with "horizon number" hn (should be in range [1,N_horizons]
+ AH_info* AH_info_array;
};
//******************************************************************************